/*
 * $Id: RunTestsParallel.java,v 1.6 2010/06/18 14:12:25 oboehm Exp $
 *
 * Copyright (c) 2009 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * (c)reated 30.11.2009 by oliver (ob@oasd.de)
 */

package patterntesting.annotation.concurrent;

import java.lang.annotation.*;

/**
 * If you mark JUnit classes with this annotation each test method in the
 * class is run in parallel.
 * <dl>
 *  <dt>WARNING</dt>
 *  <dd>
 *      Don't use this annotation together with the ExceptionFactory of
 *      PatternTesting Exception. Why? Because the ExceptionFactory is a
 *      singleton. It controls if a exception should be thrown for testing.
 *      But if the JUnit tests run in parallel you can't say which JUnit
 *      test gets the exception.
 *  </dd>
 *  <dd>
 *      Don't mix JUnit 3 and 4 style although this is possible.
 *      The RunTestsParallelAspect may get confused!
 *      And it is no good programming style.
 *  </dd>
 * </dl>
 * <b>NOTE:</b> This annotation is obsolete. It is replaced by
 * patterntesting.concurrent.junit.ParallelRunner.
 *
 * @author oliver
 * @since 30.11.2009
 * @deprecated will be removed in 1.1 (replaced by ParallelRunner)
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ElementType.TYPE})
public @interface RunTestsParallel {

    /**
     * If you want to (temporarily) disable the parallel run of test
     * methods (e.g. because you call only one test method direct) you
     * can use this attribute to disable it.
     * <br/>
     * Another (better) way to disable the parallel runs is via the system
     * property "patterntesting.runTestsParallel". Call the Java VM with
     * <tt>-Dpatterntesting.runTestsParallel=false</tt> to disable it.
     */
    boolean enabled() default true;

}
